@@ -2,14 +2,15 @@ import datetime
 import pytz
 import unittest
 from edn_format import edn_lex, edn_parse, \
-     loads, dumps, Keyword, Symbol, TaggedElement, add_tag
+    loads, dumps, Keyword, Symbol, TaggedElement, add_tag
+
 
 class ConsoleTest(unittest.TestCase):
     def test_dumping(self):
         is_exception = False
         try:
             loads("[1 true nil]")
-        except AttributeError as x:
+        except AttributeError:
             is_exception = True
         self.assertFalse(is_exception)
 
@@ -94,8 +95,11 @@ class EdnTest(unittest.TestCase):
         self.check_parse([], "[]")
         self.check_parse({"a": [1, 2, 3]},
                          '{"a" [1 2 3]}')
-        self.check_parse(datetime.datetime(2012, 12, 22, 19, 40, 18, 0, tzinfo=pytz.utc),
-                        '#inst "2012-12-22T19:40:18Z"')
+        self.check_parse(datetime.datetime(2012, 12, 22, 19, 40, 18, 0,
+                                           tzinfo=pytz.utc),
+                         '#inst "2012-12-22T19:40:18Z"')
+        self.check_parse(datetime.date(2011, 10, 9),
+                         '#inst "2011-10-09"')
         self.check_parse("|", "\"|\"")
         self.check_parse("%", "\"%\"")
         self.check_parse(['bl\\"ah'], """["bl\\"ah"]""")
@@ -124,23 +128,35 @@ class EdnTest(unittest.TestCase):
             ["+123N", "123"],
             ["123.2", "123.2"],
             ["+32.23M", "32.23M"],
-            ["3.23e10", "32300000000.0"],
-            ['#{:a (1 2 3) :b}', ['#{:a (1 2 3) :b}',
-                                  '#{(1 2 3) :a :b}',
-                                  '#{:a :b (1 2 3)}',
-                                  '#{:b :a (1 2 3)}']]
+            ["3.23e10", "32300000000.0"]
         ]
 
         for literal in EDN_LITERALS:
             step1 = literal[0]
             step2 = loads(step1)
             step3 = dumps(step2)
-#            print step1, "->", step2, "->", step3
             if isinstance(literal[1], list):
                 self.assertIn(step3, literal[1])
             else:
                 self.assertEqual(literal[1], step3)
 
+    def test_round_trip_sets(self):
+        step1 = '#{:a (1 2 3) :b}'
+        step2 = loads(step1)
+        step3 = dumps(step2)
+        step4 = loads(step3)
+        self.assertIn(Keyword("a"), step4)
+        self.assertIn(Keyword("b"), step4)
+        self.assertIn((1, 2, 3), step4)
+
+    def test_round_trip_inst_short(self):
+        step1 = '#inst "2011"'
+        step2 = loads(step1)
+        step3 = dumps(step2)
+        step4 = loads(step3)
+        self.assertEqual('#inst "2011-01-01"', step3)
+        self.assertEqual(datetime.date(2011, 1, 1), step4)
+
     def test_round_trip_same(self):
         EDN_LITERALS = (
             "nil",
@@ -174,6 +190,7 @@ class EdnTest(unittest.TestCase):
             '(1 "abc" true :ghi)',
             '{"a" 2}',
             '#inst "1985-04-12T23:20:50Z"',
+            '#inst "2011-10-09"',
             '#uuid "f81d4fae-7dec-11d0-a765-00a0c91e6bf6"',
             '#date "19/07/1984"',
             '#{{"a" 1}}',
@@ -199,12 +216,15 @@ class EdnTest(unittest.TestCase):
             step1 = literal
             step2 = loads(step1)
             step3 = dumps(step2)
-#            print step1, "->", step2, "->", step3
             self.assertEqual(step1, step3)
 
+
 class EdnInstanceTest(unittest.TestCase):
     def test_hashing(self):
-        pop_count = len(set(map(hash, ["db/id", Keyword("db/id"), Symbol("db/id")])))
+        pop_count = len(set(map(hash,
+                                ["db/id",
+                                 Keyword("db/id"),
+                                 Symbol("db/id")])))
         self.assertEqual(pop_count, 3)
 
     def test_equality(self):
